@@ -2,7 +2,7 @@
 # $Date: 2008-04-11 18:20:21 +0200 (ven, 11 avr 2008) $
 # $Revision: 600 $
 
-#    Copyright (c) 2007-2008 Dominique Dumont.
+#    Copyright (c) 2007-2010 Dominique Dumont.
 #
 #    This file is part of Config-Model-Itself.
 #
@@ -35,7 +35,7 @@
 	   warp => { follow => '?type',
 		     'rules'
 		     => { 'leaf' => {
-				     built_in   => 0,
+				     upstream_default   => 0,
 				     level => 'normal',
 				    }
 			}
@@ -80,8 +80,10 @@
 				 vt => '?value_type',
 			       },
 		     'rules'
-		     => [ '  ($t eq "leaf" and $vt eq "enum" )
-                            or $t eq "check_list"' 
+		     => [ '  ($t eq "leaf" and (   $vt eq "enum" 
+                                                or $vt eq "reference")
+                             )
+                           or $t eq "check_list"' 
 			  => {
 			      level => 'normal',
 			     } ,
@@ -90,22 +92,21 @@
 	   cargo => { type => 'leaf', value_type => 'uniline'},
 	 },
 
-      [qw/min max/]
+      'min'
       => { type => 'leaf',
 	   value_type => 'integer',
 	   level => 'hidden',
+	   description => 'minimum value',
 	   warp => { follow => {
 				'type'  => '?type',
 				'vtype' => '?value_type' ,
 			       },
 		     'rules'
-		     => [ '$type eq "hash"
-                            or
-                            (    $type eq "leaf" 
-                             and (    $vtype eq "integer" 
-                                   or $vtype eq "number" 
-                                 )
-                            ) '
+		     => [ '    $type eq "leaf" 
+                           and (    $vtype eq "integer" 
+                                 or $vtype eq "number" 
+                               )
+                          '
 			  => {
 			      level => 'normal',
 			     }
@@ -113,6 +114,54 @@
 		   }
 	 },
 
+      'max'
+      => { type => 'leaf',
+	   value_type => 'integer',
+	   level => 'hidden',
+	   description => 'maximum value',
+	   warp => { follow => {
+				'type'  => '?type',
+				'vtype' => '?value_type' ,
+			       },
+		     'rules'
+		     => [ '    $type eq "leaf" 
+                           and (    $vtype eq "integer" 
+                                 or $vtype eq "number" 
+                               )
+                          '
+			  => {
+			      level => 'normal',
+			     }
+			]
+		   }
+	 },
+
+      'min_index'
+      => { type => 'leaf',
+	   value_type => 'integer',
+	   level => 'hidden',
+	   description => 'minimum number of indexes',
+	   warp => { follow => {'type'  => '?type',},
+		     'rules'
+		     => [ '$type eq "hash" or $type eq "list"'
+			  => {level => 'normal',},
+			]
+		   }
+	 },
+
+      'max_index'
+      => { type => 'leaf',
+	   value_type => 'integer',
+	   level => 'hidden',
+	   description => 'maximum number of keys',
+	   warp => { follow => {'type'  => '?type',},
+		     'rules'
+		     => [ '$type eq "hash" or $type eq "list"'
+			  => {level => 'normal',},
+			]
+		   }
+	 },
+
       'default'
       => { type => 'leaf',
 	   level => 'hidden',
@@ -128,7 +177,7 @@
 		   }
 	 },
 
-      'built_in'
+      'upstream_default'
       => { type => 'leaf',
 	   level => 'hidden',
 	   value_type => 'uniline',
@@ -180,7 +229,7 @@
 		   },
 	 },
 
-      'built_in_list'
+      'upstream_default_list'
       => { type => 'check_list',
 	   level => 'hidden',
 	   refer_to => '- choice',
@@ -202,22 +251,6 @@
 
       # hash element
 
-      'index_type' 
-      => { type => 'leaf',
-	   value_type => 'enum',
-	   level      => 'hidden' ,
-	   warp => { follow => '?type',
-		     'rules'
-		     => { 'hash' => {
-				     level => 'important',
-				     #mandatory => 1,
-				     choice => [qw/string integer/] ,
-				    }
-			}
-		   },
-	   description => 'Specify the type of allowed index for the hash. "String" means no restriction.',
-	 },
-
       # list element
 
 
