@@ -76,7 +76,7 @@
 	       => { 'warped_node' 
 		    => {
 			level => 'normal',
-			built_in => 0 ,
+			upstream_default => 0 ,
 		       },
 		  }
 	     },
@@ -124,6 +124,7 @@
 
       'compute' 
       => { type => 'warped_node',
+	   level => 'hidden',
 
 	   follow => { t  => '- type',},
 	   'rules' => [ '$t  eq "leaf"'
@@ -135,6 +136,20 @@
 	   description => "compute the default value according to a formula and value from other elements in the configuration tree.",
 	 },
 
+      'migrate_from' 
+      => { type => 'warped_node',
+	   level => 'hidden',
+
+	   follow => { t  => '- type',},
+	   'rules' => [ '$t  eq "leaf"'
+			=> {
+			    level => 'normal',
+			    config_class_name => 'Itself::MigratedValue',
+			   },
+		      ],
+	   description => "Specify an upgrade path from an old value and compute the value to store in the new element.",
+	 },
+
 
       # hash element
 
