@@ -1,6 +1,6 @@
 # $Author: ddumont $
-# $Date: 2009-02-24 13:08:18 +0100 (Tue, 24 Feb 2009) $
-# $Revision: 861 $
+# $Date: 2009-06-23 13:41:22 +0200 (Tue, 23 Jun 2009) $
+# $Revision: 979 $
 
 #    Copyright (c) 2007-2008 Dominique Dumont.
 #
@@ -142,7 +142,6 @@
    => [
        value_type => 'specify the type of a leaf element.',
        default => 'Specify default value. This default value will be written in the configuration data',
-       built_in => 'Another way to specify a default value. But this default value is considered as "built_in" the application and is not written in the configuration data (unless modified)',
        follow_keys_from => 'this hash will contain the same keys as the hash pointed by the path string',
        allow_keys_from =>'this hash will allow keys from the keys of the hash pointed by the path string', 
        ordered => 'keep track of the order of the elements of this hash',
@@ -152,7 +151,6 @@
        allow_keys => 'specify a set of allowed keys',
        default_with_init => 'specify a set of keys to create and initialization on some elements . E.g. \' foo => "X=Av Y=Bv", bar => "Y=Av Z=Cz"\' ',
        convert => 'When stored, the value will be converted to uppercase (uc) or lowercase (lc).',
-       choice => 'Specify the possible values',
        help => 'Specify help string specific to possible values. E.g for "light" value, you could write " red => \'stop\', green => \'walk\' ',
        replace => 'Used for enum to substitute one value with another. This parameter must be used to enable user to upgrade a configuration with obsolete values. The old value is the key of the hash, the new one is the value of the hash',
       ],
